# Prompt Smith Python SDK

- [PyPi](https://pypi.org/project/promtsmithsdk/)
- [Github](https://github.com/PromptSmith-OSS/promptsmith-python-sdk)

The Prompt Smith Python SDK is a Python package that provides a simple way to interact with the Prompt Smith API. 
The SDK is designed to make it easy to integrate the Prompt Smith API into your Python LLM RAG and Agent applications.


This SDK is built on top of the Prompt Smith API.